:mod:`API`
----------------------------

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation


Accessor
********

.. automodule:: cf_pandas.accessor
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

``cf-pandas`` utilities
***********************

.. automodule:: cf_pandas.utils
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

Reg class for writing regular expressions
*****************************************

.. automodule:: cf_pandas.reg
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

Vocab class for handling custom variable-selection vocabularies
***************************************************************

.. automodule:: cf_pandas.vocab
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

widget class for easy human selection of variables to exactly match
*******************************************************************

.. automodule:: cf_pandas.widget
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:
